@@ -31,6 +31,23 @@ func TestDateHistogramAggregation(t *testing.T) {
 	}
 }
 
+func TestDateHistogramAggregationWithKeyedResponse(t *testing.T) {
+	agg := NewDateHistogramAggregation().Field("date").Interval("year").Missing("1900").Keyed(true)
+	src, err := agg.Source()
+	if err != nil {
+		t.Fatal(err)
+	}
+	data, err := json.Marshal(src)
+	if err != nil {
+		t.Fatalf("marshaling to JSON failed: %v", err)
+	}
+	got := string(data)
+	expected := `{"date_histogram":{"field":"date","interval":"year","keyed":true,"missing":"1900"}}`
+	if got != expected {
+		t.Errorf("expected\n%s\n,got:\n%s", expected, got)
+	}
+}
+
 func TestDateHistogramAggregationWithMissing(t *testing.T) {
 	agg := NewDateHistogramAggregation().Field("date").Interval("year").Missing("1900")
 	src, err := agg.Source()
